==> haskell-quic-0.1.16-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quic
version:              0.1.16
visibility:           public
id:                   quic-0.1.16-KTgL1VyPRSEBBILdldVQUw
key:                  quic-0.1.16-KTgL1VyPRSEBBILdldVQUw
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  3a9801614e20f31dcef3f844bcbd90b9
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Integer
    Network.QUIC.Types.Packet Network.QUIC.Types.Queue
    Network.QUIC.Types.Resumption Network.QUIC.Types.Time
    Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quic-0.1.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quic-0.1.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quic-0.1.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.16-KTgL1VyPRSEBBILdldVQUw
depends:
    array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-DtLhCS1yMgY3iFYZkoZd12
    bytestring-0.11.5.3 containers-0.6.7
    crypto-token-0.1.1-HgiSpaePWyzHUPyTCSJPFw
    crypton-1.0.2-BgHjNZ2cORQ1QFrdVzHSiv
    crypton-x509-1.7.7-5nzuXk7GTVKLkRhpPA7ICy
    crypton-x509-system-1.6.7-4myax5UMeSe5acSk6gayA9
    data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb
    fast-logger-3.2.3-EQh5ywpVTmYEyKp9JHIZBo filepath-1.4.2.2
    iproute-1.7.15-5EIx0b7JR6f5WZElmDysSe
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-KV3OkCyx0pcI1DdyD3ZbeB
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    network-control-0.0.2-CAwIavTOfI1GUaRDLHS24z
    network-udp-0.0.0-KVMmg5GnvjGEAbDTOeGhr4
    random-1.2.1.3-8vZ5nHC8xeMEF0rmgzNDZj
    serialise-0.2.6.1-1JlVc1W0TYp1BmEUQgn1gc stm-2.5.1.0
    tls-2.0.6-44Nt7FWyzPN6N6ncfxfgeV
    unix-time-0.4.17-7wlM7x211TvKrlzJzF93NY
    unliftio-0.2.25.1-DYznH1vHiFW9UOG5RP6OX5
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quic-0.1.16-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quic
version:              0.1.16
visibility:           public
id:                   quic-0.1.16-2rQS6NBCZqALCpHSjrab68
key:                  quic-0.1.16-2rQS6NBCZqALCpHSjrab68
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  fc6192f038fa62baaefa9a9d9677fc1e
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Integer
    Network.QUIC.Types.Packet Network.QUIC.Types.Queue
    Network.QUIC.Types.Resumption Network.QUIC.Types.Time
    Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quic-0.1.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quic-0.1.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quic-0.1.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.16-2rQS6NBCZqALCpHSjrab68
depends:
    array-0.5.4.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-C3cPjjLt0AO1rbHXbT6P0Z
    bytestring-0.11.5.3 containers-0.6.7
    crypto-token-0.1.1-JAt9aepuf2gLRW0JDb42Rt
    crypton-1.0.2-JusZyiOHHprBKng1nU1y0l
    crypton-x509-1.7.7-EJdtcTdiycZcO898dmjv5
    crypton-x509-system-1.6.7-BYGW4K0d6luAVwLRN266rS
    data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb
    fast-logger-3.2.3-DeT2TRpuu17FRRtRFZyjKS filepath-1.4.2.2
    iproute-1.7.15-DC1DWuYV7Jl1nOPDIRybEO
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-9WwAYDZyp2nAB4XV6sI63l
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    network-control-0.0.2-I3TIsuhFxIKWYTr94fmuz
    network-udp-0.0.0-9v0Rukphj0I9A8vlv27eJO
    random-1.2.1.3-5GClgMcgHINEWJGyng3KHI
    serialise-0.2.6.1-1HByF3LXyfU8VfOTOtWiaZ stm-2.5.1.0
    tls-2.0.6-FzrGL1wjmiU777K0MMyiCb
    unix-time-0.4.17-JLnnAsB1Ekh9Xz73jsBlkP
    unliftio-0.2.25.1-HBosFkLH3dKBKd3HpxN2GY
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
